==> choonvdeliver-0.1.4.tar.gz: choonvdeliver-0.1.4/src/lib/str_getpath.c <==
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*-  */
/* str_getpath.c
 *
 * Copyright (C) 2019  Giam Teck Choon <choon@choon.net>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

#include <errno.h>
#include <bglibs/str.h>
#include "is_file.h"
#include "is_executable.h"

/*
 * prog found, 1 is returned otherwise 0 is returned.  On error, -1 is
 * returned, and errno is set appropriately.
 */
int str_getpath(const char *prog, str *s)
{
	str t = {0,0,0};
	if (!str_copy2s(&t, "/usr/local/bin/", prog)) {
		str_free(&t);
		errno = ENOMEM;
		return -1;
	}
	if (is_file(t.s) && is_executable(t.s)) {
		if (!str_copys(s, t.s)) {
			str_free(&t);
			errno = ENOMEM;
			return -1;
		}
		str_free(&t);
		return 1;
	}
	if (!str_copy2s(&t, "/usr/local/sbin/", prog)) {
		str_free(&t);
		errno = ENOMEM;
		return -1;
	}
	if (is_file(t.s) && is_executable(t.s)) {
		if (!str_copys(s, t.s)) {
			str_free(&t);
			errno = ENOMEM;
			return -1;
		}
		str_free(&t);
		return 1;
	}
	if (!str_copy2s(&t, "/usr/bin/", prog)) {
		str_free(&t);
		errno = ENOMEM;
		return -1;
	}
	if (is_file(t.s) && is_executable(t.s)) {
		if (!str_copys(s, t.s)) {
			str_free(&t);
			errno = ENOMEM;
			return -1;
		}
		str_free(&t);
		return 1;
	}
	if (!str_copy2s(&t, "/usr/sbin/", prog)) {
		str_free(&t);
		errno = ENOMEM;
		return -1;
	}
	if (is_file(t.s) && is_executable(t.s)) {
		if (!str_copys(s, t.s)) {
			str_free(&t);
			errno = ENOMEM;
			return -1;
		}
		str_free(&t);
		return 1;
	}
	if (getenv("HOME")) {
		if (!str_copy3s(&t, getenv("HOME"), "/bin/", prog)) {
			str_free(&t);
			errno = ENOMEM;
			return -1;
		}
		if (is_file(t.s) && is_executable(t.s)) {
			if (!str_copys(s, t.s)) {
				str_free(&t);
				errno = ENOMEM;
				return -1;
			}
			str_free(&t);
			return 1;
		}
	}
	return 0;
}

==> choonvdeliver-0.1.7.tar.gz: choonvdeliver-0.1.7/src/lib/str_getpath.c <==
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*-  */
/* 
 * Copyright (C) 2019 by Giam Teck Choon
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

/*!
 *  @file str_getpath.c
 *  @date 21 Sep 2019
 *  @author Giam Teck Choon
 *  @brief Function for str_getpath()
 *  @bug No known bugs.
 */

#include <errno.h>
#include <bglibs/str.h>
#include "is_file.h"
#include "is_executable.h"

/*!
 *  @brief Get the program absolute path.
 *
 *  @param prog Program name string.
 *  @param s Record the absolute path of program name.
 *  @return On success, 1 is returned. Otherwise, 0 is returned.
 *          On error, -1 is returned, and errno is set appropriately.
 */
int str_getpath(const char *prog, str *s)
{
	str t = {0,0,0};
	if (!str_copy2s(&t, "/usr/local/bin/", prog)) {
		str_free(&t);
		errno = ENOMEM;
		return -1;
	}
	if (is_file(t.s) && is_executable(t.s)) {
		if (!str_copys(s, t.s)) {
			str_free(&t);
			errno = ENOMEM;
			return -1;
		}
		str_free(&t);
		return 1;
	}
	if (!str_copy2s(&t, "/usr/local/sbin/", prog)) {
		str_free(&t);
		errno = ENOMEM;
		return -1;
	}
	if (is_file(t.s) && is_executable(t.s)) {
		if (!str_copys(s, t.s)) {
			str_free(&t);
			errno = ENOMEM;
			return -1;
		}
		str_free(&t);
		return 1;
	}
	if (!str_copy2s(&t, "/usr/bin/", prog)) {
		str_free(&t);
		errno = ENOMEM;
		return -1;
	}
	if (is_file(t.s) && is_executable(t.s)) {
		if (!str_copys(s, t.s)) {
			str_free(&t);
			errno = ENOMEM;
			return -1;
		}
		str_free(&t);
		return 1;
	}
	if (!str_copy2s(&t, "/usr/sbin/", prog)) {
		str_free(&t);
		errno = ENOMEM;
		return -1;
	}
	if (is_file(t.s) && is_executable(t.s)) {
		if (!str_copys(s, t.s)) {
			str_free(&t);
			errno = ENOMEM;
			return -1;
		}
		str_free(&t);
		return 1;
	}
	if (getenv("HOME")) {
		if (!str_copy3s(&t, getenv("HOME"), "/bin/", prog)) {
			str_free(&t);
			errno = ENOMEM;
			return -1;
		}
		if (is_file(t.s) && is_executable(t.s)) {
			if (!str_copys(s, t.s)) {
				str_free(&t);
				errno = ENOMEM;
				return -1;
			}
			str_free(&t);
			return 1;
		}
	}
	return 0;
}
